@@ -1,5 +1,6 @@
 from django import forms
-from coop_cms.models import NavType, NavNode, Newsletter, NewsletterSending, Link, Document, Fragment, BaseArticle
+from coop_cms.models import NavType, NavNode, Newsletter, NewsletterSending, Link, Document, Fragment, BaseArticle, MediaFilter
+from coop_cms.models import ImageSize
 from django.contrib.contenttypes.models import ContentType
 from settings import get_navigable_content_types
 from django.core.exceptions import ValidationError
@@ -65,11 +66,12 @@ class ArticleForm(AlohaEditableModelForm):
         no_aloha_widgets = ('logo',)
 
     def set_logo_size(self, logo_size=None, logo_crop=None):
-        thumbnail_src = self.logo_thumbnail(logo_size, logo_crop)
-        update_url = reverse('coop_cms_update_logo', args=[self.article.id])
-        self.fields['logo'].widget = ImageEdit(update_url,
-            thumbnail_src.url if thumbnail_src else '',
-            attrs={"class": "resizable"})
+        if self.fields.has_key('logo'):
+            thumbnail_src = self.logo_thumbnail(logo_size, logo_crop)
+            update_url = reverse('coop_cms_update_logo', args=[self.article.id])
+            self.fields['logo'].widget = ImageEdit(update_url,
+                thumbnail_src.url if thumbnail_src else '',
+                attrs={"class": "resizable"})
 
     def logo_thumbnail(self, logo_size=None, logo_crop=None):
         if self.article:
@@ -185,12 +187,53 @@ class ArticleAdminForm(forms.ModelForm):
             'title': forms.TextInput(attrs={'size': 100})
         }
 
-class AddImageForm(forms.Form):
-    image = forms.ImageField(required=True, label = _('Image'),)
-    descr = forms.CharField(required=False, widget=forms.TextInput(
+class AddImageForm(floppyforms.Form):
+    image = floppyforms.ImageField(required=True, label = _('Image'),)
+    descr = floppyforms.CharField(required=False, widget=forms.TextInput(
         attrs={'size': '35', 'placeholder': _(u'Optional description'),}),
         label = _('Description'),
     )
+    filters = floppyforms.MultipleChoiceField(required=False, label=_(u"Filters"),
+        help_text=_(u"Choose betwwen tags to find images more easily"))
+    size = floppyforms.ChoiceField(required=False, label=_(u"Size"),
+        help_text=_(u"Define a size if you want to resize the image"))
+    
+    def __init__(self, *args, **kwargs):
+        super(AddImageForm, self).__init__(*args, **kwargs)
+        #Media filters
+        qs = MediaFilter.objects.all()
+        if qs.count():
+            self.fields['filters'].choices = [(x.id, x.name) for x in qs]
+            try:
+                self.fields['filters'].widget = ChosenSelectMultiple(
+                    choices=self.fields['filters'].choices, force_template=True,
+                )
+            except NameError:
+                #print 'No ChosenSelectMultiple'
+                pass
+        else:
+            self.fields['filters'].widget = floppyforms.HiddenInput()
+            
+        #Image size
+        qs = ImageSize.objects.all()
+        if qs.count():
+            self.fields['size'].choices = [('', '')]+[(x.id, unicode(x)) for x in qs]
+        else:
+            self.fields['size'].widget = floppyforms.HiddenInput()
+            
+            
+    def clean_filters(self):
+        filters = self.cleaned_data['filters']
+        return [MediaFilter.objects.get(id=pk) for pk in filters]
+    
+    def clean_size(self):
+        size_id = self.cleaned_data['size']
+        if not size_id:
+            return None
+        try:
+            return ImageSize.objects.get(id=size_id)
+        except (ValueError, ImageSize.DoesNotExist):
+            raise ValidationError(_(u"Invalid choice"))
 
 class AddDocForm(forms.ModelForm):
     class Meta:
@@ -252,6 +295,7 @@ class NewArticleForm(WithNavigationModelForm):
             self.fields["template"] = forms.ChoiceField(choices=choices)
         else:
             self.fields["template"] = forms.CharField()
+        self.fields["title"].required = True
         self.fields["title"].widget = forms.TextInput(attrs={'size': 30})
 
 
