@@ -30,7 +30,8 @@ import urlparse
 from sorl.thumbnail import default
 from django.contrib.sites.models import Site
 ADMIN_THUMBS_SIZE = '60x60'
-
+import logging
+logger = logging.getLogger("coop_cms")
 
 def get_object_label(content_type, object):
     """
@@ -153,6 +154,9 @@ class NavNode(models.Model):
     def has_children(self):
         return self.get_children(True).count()
     
+    def get_children_count(self):
+        return self.get_children(True).count()
+    
     def get_children_navigation(self):
         return self.get_children(True)
 
@@ -183,10 +187,15 @@ class NavNode(models.Model):
             self.id, li_content, u''.join(children_li), "in_nav" if self.in_navigation else "out_nav"
         )
 
-    def _get_li_content(self, li_template):
+    def _get_li_content(self, li_template, node_pos=0, total_nodes=0):
         if li_template:
             t = li_template if hasattr(li_template, 'render') else get_template(li_template)
-            return t.render(Context({'node': self}))
+            return t.render(
+                Context({
+                    'node': self, 'STATIC_URL': settings.STATIC_URL,
+                    'node_pos': node_pos, 'total_nodes': total_nodes,
+                })
+            )
         else:
             url = self.get_absolute_url()
             if url == None:
@@ -212,14 +221,21 @@ class NavNode(models.Model):
     #    t = get_template(template_name)
     #    return t.render(Context({'node': self}))
 
-    def as_navigation(self, li_template=None, css_class="", ul_template=None, li_args=None, active_class="active-node"):
+    def as_navigation(self, li_node=None, li_template=None, css_class="",
+        ul_template=None, li_args=None, active_class="active-node", node_pos=0, total_nodes=0):
         #Display the node and his children as nested ul and li html tags.
         #li_template is a custom template that can be passed
 
         if not self.in_navigation:
             return ""
+        
+        children = self.get_children(in_navigation=True)
+        children_count = self.get_children_count()
 
-        children_li = [child.as_navigation(li_template, css_class) for child in self.get_children(in_navigation=True)]
+        children_li = [
+            child.as_navigation(li_node, li_template, css_class, node_pos=i+1, total_nodes=children_count)
+            for (i, child) in enumerate(children)
+        ]
         ul_format = self._get_ul_format(ul_template)
         children_html = ul_format.format(u''.join(children_li)) if children_li else ""
         args = self._get_li_args(li_args)
@@ -227,8 +243,11 @@ class NavNode(models.Model):
             css_class = u'class="{0} {1}"'.format(css_class, active_class if self.is_active_node() else "")
         else:
             css_class=""
-        return u'<li {0} {1}>{2}{3}</li>'.format(
-            css_class, args, self._get_li_content(li_template), children_html)
+        if not li_node:
+            return u'<li {0} {1}>{2}{3}</li>'.format(
+                css_class, args, self._get_li_content(li_template), children_html)
+        else:
+            return self._get_li_content(li_node, node_pos, total_nodes)
 
     def as_breadcrumb(self, li_template=None, css_class=""):
         html = self.parent.as_breadcrumb(li_template) if self.parent else u""
@@ -302,7 +321,7 @@ class ArticleCategory(models.Model):
         return reverse('coop_cms_articles_category', args=[self.slug])
     
     def get_articles_qs(self):
-        return get_article_class().objects.filter(
+        return get_article_class().objects.filter(sites__id=settings.SITE_ID,
             category=self, publication=BaseArticle.PUBLISHED).order_by('publication_date')
 
     class Meta:
@@ -640,12 +659,38 @@ def get_img_folder(instance, filename):
         img_root = settings.IMAGE_FOLDER
     except AttributeError:
         img_root = 'img'
+    
+    return u'{0}/{1}'.format(img_root, filename)
 
-    return u'{0}/{1}/{2}'.format(img_root,
-        instance.created.strftime('%Y%d%m%H%M%S'), filename)
+    #return u'{0}/{1}/{2}'.format(img_root,
+    #    instance.created.strftime('%Y%d%m%H%M%S'), filename)
+
+class MediaFilter(models.Model):
+    name = models.CharField(_('name'), max_length=100)
+    
+    class Meta:
+        verbose_name = _(u'media filter')
+        verbose_name_plural = _(u'media filters')
+        
+    def __unicode__(self):
+        return self.name
+    
+class ImageSize(models.Model):
+    name = models.CharField(_(u'name'), max_length=100)
+    size = models.CharField(_(u'size'), max_length=100)
+    crop = models.CharField(_(u'crop'), max_length=100, blank=True, default="")
+    
+    class Meta:
+        verbose_name = _(u'Image size')
+        verbose_name_plural = _(u'Image sizes')
+        
+    def __unicode__(self):
+        return u"{0} ({1}{2})".format(self.name, self.size, (" "+self.crop if self.crop else ""))
 
 class Media(TimeStampedModel):
     name = models.CharField(_('name'), max_length=200, blank=True, default='')
+    filters = models.ManyToManyField(MediaFilter, blank=True, default=None, verbose_name=_(u"filters"))
+    ordering = models.IntegerField(_(u"ordering"), default=100)
 
     def __unicode__(self):
         return self.name
@@ -654,17 +699,24 @@ class Media(TimeStampedModel):
         abstract = True
 
 class Image(Media):
-    file = models.ImageField(_('file'), upload_to=get_img_folder)
-
+    file = models.ImageField(_(u'file'), upload_to=get_img_folder)
+    size = models.ForeignKey(ImageSize, default=None, blank=True, null=True, verbose_name=_(u"size"))
+    
     def as_thumbnail(self):
         try:
             return sorl_thumbnail.backend.get_thumbnail(self.file.file, "64x64", crop='center')
         except Exception, msg:
             return self.file
-        
 
     def get_absolute_url(self):
-        return self.file.url
+        if not self.size:
+            return self.file.url
+        try:
+            crop = self.size.crop or None
+            return sorl_thumbnail.backend.get_thumbnail(self.file.file, self.size.size, crop=crop).url
+        except Exception, msg:
+            logger.error("Image can not resize: {0}".format(self.size))
+            return self.file.url
 
     class Meta:
         verbose_name = _(u'image')
@@ -688,8 +740,10 @@ class Document(Media):
         name, ext = os.path.splitext(filename)
         filename = slugify(name) + ext
         
-        return u'{0}/{1}/{2}'.format(doc_root,
-            self.created.strftime('%Y%d%m%H%M%S'), filename)
+        return u'{0}/{1}'.format(doc_root, filename)
+
+        #return u'{0}/{1}/{2}'.format(doc_root,
+        #    self.created.strftime('%Y%d%m%H%M%S'), filename)
 
     file = models.FileField(_('file'), upload_to=get_doc_folder)
     is_private = models.BooleanField(_('is private'), default=False,
@@ -729,9 +783,10 @@ class PieceOfHtml(models.Model):
     div_id = models.CharField(verbose_name=_(u"identifier"), max_length=100, db_index=True)
     #content = HTMLField(content_cleaner, verbose_name=_(u"content"), default="", blank=True)
     content = models.TextField(_(u"content"), default="", blank=True)
+    extra_id = models.CharField(verbose_name=_(u"extra identifier"), blank=True, default="", max_length=100, db_index=True)
 
     def __unicode__(self):
-        return self.div_id
+        return u" ".join([self.div_id, self.extra_id])
 
     class Meta:
         verbose_name = _(u'piece of HTML')
@@ -742,9 +797,9 @@ def remove_from_navigation(sender, instance, **kwargs):
     if hasattr(instance, 'id'):
         try:
             ct = ContentType.objects.get_for_model(instance)
-            node = NavNode.objects.get(content_type=ct, object_id=instance.id)
-            node.delete()
-        except (NavNode.DoesNotExist, ContentType.DoesNotExist):
+            nodes = NavNode.objects.filter(content_type=ct, object_id=instance.id)
+            nodes.delete()
+        except (ContentType.DoesNotExist):
             pass
 pre_delete.connect(remove_from_navigation)
 
