@@ -35,6 +35,8 @@ from generic_views import EditableObjectView
 from django.forms.models import modelformset_factory
 import logging
 logger = logging.getLogger("coop_cms")
+import itertools
+from coop_cms.settings import cms_no_homepage
 
 def get_article_template(article):
     template = article.template
@@ -53,6 +55,8 @@ def tree_map(request):
 def homepage(request):
     try:
         article = get_article_class().objects.get(homepage_for_site__id=settings.SITE_ID, sites=settings.SITE_ID)
+        if cms_no_homepage():
+            raise Http404
         return HttpResponseRedirect(article.get_absolute_url())
     except get_article_class().DoesNotExist:
         return HttpResponseRedirect(reverse('coop_cms_view_all_articles'))
@@ -246,27 +250,44 @@ def publish_article(request, url):
 @login_required
 def show_media(request, media_type):
     try:
+        if not request.user.is_staff:
+            raise PermissionDenied
+        
         is_ajax = request.GET.get('page', 0)
+        media_filter = request.GET.get('media_filter', 0)
     
         if request.session.get("coop_cms_media_doc", False):
             media_type = 'document' #force the doc
             del request.session["coop_cms_media_doc"]
     
         if media_type == 'image':
+            qs = models.Image.objects.all().order_by("ordering", "-created")
             context = {
-                'images': models.Image.objects.all().order_by("-created"),
                 'media_url': reverse('coop_cms_media_images'),
                 'media_slide_template': 'coop_cms/slide_images_content.html',
             }
         else:
+            media_type = "document"
+            qs = models.Document.objects.all().order_by("ordering", "-created")
             context = {
-                'documents': models.Document.objects.all().order_by("-created"),
                 'media_url': reverse('coop_cms_media_documents'),
                 'media_slide_template': 'coop_cms/slide_docs_content.html',
             }
+            
         context['is_ajax'] = is_ajax
         context['media_type'] = media_type
-    
+        
+        media_filters = [media.filters.all() for media in qs.all()] # list of lists of media_filters
+        media_filters = itertools.chain(*media_filters) #flat list of media_filters
+        context['media_filters'] = sorted(
+            list(set(media_filters)), key=lambda mf: mf.name.upper()
+        )#flat list of unique media filters sorted by alphabetical order (ignore case)
+        
+        if int(media_filter):
+            qs = qs.filter(filters__id=media_filter)
+            context['media_filter'] = int(media_filter)
+        context[media_type+'s'] = qs
+        
         t = get_template('coop_cms/slide_base.html')
         html = t.render(RequestContext(request, context))
     
@@ -285,6 +306,10 @@ def show_media(request, media_type):
 @login_required
 def upload_image(request):
     try:
+        
+        if not request.user.has_perm("coop_cms.add_image"):
+            raise PermissionDenied()
+        
         if request.method == "POST":
             form = forms.AddImageForm(request.POST, request.FILES)
             if form.is_valid():
@@ -293,8 +318,15 @@ def upload_image(request):
                 if not descr:
                     descr = os.path.splitext(src.name)[0]
                 image = models.Image(name=descr)
+                image.size = form.cleaned_data["size"]
                 image.file.save(src.name, src)
                 image.save()
+                
+                filters = form.cleaned_data['filters']
+                if filters:
+                    image.filters.add(*filters)
+                    image.save()
+                
                 return HttpResponse("close_popup_and_media_slide")
         else:
             form = forms.AddImageForm()
@@ -312,6 +344,9 @@ def upload_image(request):
 @login_required
 def upload_doc(request):
     try:
+        if not request.user.has_perm("coop_cms.add_document"):
+            raise PermissionDenied()
+        
         if request.method == "POST":
             form = forms.AddDocForm(request.POST, request.FILES)
             if form.is_valid():
@@ -1035,13 +1070,13 @@ def edit_fragments(request):
     )
 
 def articles_category(request, slug):
-    category = get_object_or_404(models.ArticleCategory, slug=slug)
+    category = get_object_or_404(models.ArticleCategory, slug=slug, sites__id=settings.SITE_ID)
     
     if not request.user.has_perm('can_view_category', category):
         raise PermissionDenied()
     
-    articles = get_article_class().objects.filter(
-        category=category, publication=models.BaseArticle.PUBLISHED).order_by("-publication_date")
+    articles = category.get_articles_qs().filter(
+        publication=models.BaseArticle.PUBLISHED).order_by("-publication_date")
     
     if articles.count()==0:
         raise Http404
@@ -1065,25 +1100,26 @@ def change_language(request):
     except ImportError:
         raise Http404
     
-    next = request.REQUEST.get('next', None)
-    if not next:
+    next_url = request.REQUEST.get('next', None)
+    if not next_url:
         try:
             url = urlparse(request.META.get('HTTP_REFERER'))
             if url:
-                next = url.path
+                next_url = url.path
         except:
             pass
-    if not next:
-        next = '/'
     
     if request.method == 'POST':
-        
         lang_code = request.POST.get('language', None)
+        after_change_url = request.POST.get('next_url_after_change_lang', None)
+        if after_change_url:
+            next_url = after_change_url
+            
         if lang_code and check_for_language(lang_code):
             
             #locale is the current language
             #path is the locale-independant url
-            locale, path = localeurl_utils.strip_path(next)
+            locale, path = localeurl_utils.strip_path(next_url)
             
             Article = get_article_class()
             try:
@@ -1096,19 +1132,23 @@ def change_language(request):
                 
             except Article.DoesNotExist:
                 next_article = None
-                
+            
             if hasattr(request, 'session'):
                 request.session['django_language'] = lang_code
             else:
                 response.set_cookie(settings.LANGUAGE_COOKIE_NAME, lang_code)
             activate(lang_code)
-                
+            
             if next_article:
-                next = next_article.get_absolute_url()
+                next_url = next_article.get_absolute_url()
             else:
-                next = localeurl_utils.locale_path(path, lang_code)
-
-    return HttpResponseRedirect(next)
+                next_url = localeurl_utils.locale_path(path, lang_code)
+                    
+                    
+    if not next_url:
+        next_url = '/'
+    
+    return HttpResponseRedirect(next_url)
     
 class ArticleView(EditableObjectView):
     model = get_article_class()
